/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 208 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 71 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 75 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 78 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 81 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 135 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qvector.h>
#line 84 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qimage.sip"
#include <qimage.h>
#line 87 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpygui_qvector.sip"
#include <qvector.h>
#line 90 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 93 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 96 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 30 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qimage.h>
#include <qvector.h>
#line 100 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 103 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 108 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 111 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 114 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 117 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 120 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 123 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 126 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 129 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 132 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 135 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 138 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 141 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 144 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 147 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"


class sipQtDataVisualization_QCustom3DVolume : public ::QtDataVisualization::QCustom3DVolume
{
public:
    sipQtDataVisualization_QCustom3DVolume(::QObject*);
    sipQtDataVisualization_QCustom3DVolume(const ::QVector3D&, const ::QVector3D&, const ::QQuaternion&, int, int, int, ::QVector<unsigned char>*, ::QImage::Format, const ::QVector<uint>&, ::QObject*);
    virtual ~sipQtDataVisualization_QCustom3DVolume();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_QCustom3DVolume(const sipQtDataVisualization_QCustom3DVolume &);
    sipQtDataVisualization_QCustom3DVolume &operator = (const sipQtDataVisualization_QCustom3DVolume &);

    char sipPyMethods[7];
};

sipQtDataVisualization_QCustom3DVolume::sipQtDataVisualization_QCustom3DVolume(::QObject*a0): ::QtDataVisualization::QCustom3DVolume(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QCustom3DVolume::sipQtDataVisualization_QCustom3DVolume(const ::QVector3D& a0, const ::QVector3D& a1, const ::QQuaternion& a2, int a3, int a4, int a5, ::QVector<unsigned char>*a6, ::QImage::Format a7, const ::QVector<uint>& a8, ::QObject*a9): ::QtDataVisualization::QCustom3DVolume(a0, a1, a2, a3, a4, a5, a6, a7, a8, a9), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QCustom3DVolume::~sipQtDataVisualization_QCustom3DVolume()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_QCustom3DVolume::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_QCustom3DVolume);

    return ::QtDataVisualization::QCustom3DVolume::metaObject();
}

int sipQtDataVisualization_QCustom3DVolume::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::QCustom3DVolume::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_QCustom3DVolume, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_QCustom3DVolume::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_QCustom3DVolume, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::QCustom3DVolume::qt_metacast(_clname));
}

void sipQtDataVisualization_QCustom3DVolume::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DVolume::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DVolume::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DVolume::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DVolume::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DVolume::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DVolume::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DVolume::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DVolume::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DVolume::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_QCustom3DVolume::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::QCustom3DVolume::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtDataVisualization_QCustom3DVolume::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::QCustom3DVolume::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setTextureWidth, "setTextureWidth(self, value: int)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureWidth(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0))
        {
            sipCpp->setTextureWidth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setTextureWidth, doc_QtDataVisualization_QCustom3DVolume_setTextureWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_textureWidth, "textureWidth(self) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureWidth(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->textureWidth();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_textureWidth, doc_QtDataVisualization_QCustom3DVolume_textureWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setTextureHeight, "setTextureHeight(self, value: int)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureHeight(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0))
        {
            sipCpp->setTextureHeight(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setTextureHeight, doc_QtDataVisualization_QCustom3DVolume_setTextureHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_textureHeight, "textureHeight(self) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureHeight(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureHeight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->textureHeight();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_textureHeight, doc_QtDataVisualization_QCustom3DVolume_textureHeight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setTextureDepth, "setTextureDepth(self, value: int)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureDepth(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0))
        {
            sipCpp->setTextureDepth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setTextureDepth, doc_QtDataVisualization_QCustom3DVolume_setTextureDepth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_textureDepth, "textureDepth(self) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureDepth(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureDepth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->textureDepth();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_textureDepth, doc_QtDataVisualization_QCustom3DVolume_textureDepth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setTextureDimensions, "setTextureDimensions(self, width: int, height: int, depth: int)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureDimensions(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureDimensions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biii", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->setTextureDimensions(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setTextureDimensions, doc_QtDataVisualization_QCustom3DVolume_setTextureDimensions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_textureDataWidth, "textureDataWidth(self) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureDataWidth(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureDataWidth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->textureDataWidth();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_textureDataWidth, doc_QtDataVisualization_QCustom3DVolume_textureDataWidth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setSliceIndexX, "setSliceIndexX(self, value: int)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceIndexX(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceIndexX(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0))
        {
            sipCpp->setSliceIndexX(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setSliceIndexX, doc_QtDataVisualization_QCustom3DVolume_setSliceIndexX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_sliceIndexX, "sliceIndexX(self) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceIndexX(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceIndexX(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->sliceIndexX();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_sliceIndexX, doc_QtDataVisualization_QCustom3DVolume_sliceIndexX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setSliceIndexY, "setSliceIndexY(self, value: int)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceIndexY(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceIndexY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0))
        {
            sipCpp->setSliceIndexY(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setSliceIndexY, doc_QtDataVisualization_QCustom3DVolume_setSliceIndexY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_sliceIndexY, "sliceIndexY(self) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceIndexY(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceIndexY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->sliceIndexY();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_sliceIndexY, doc_QtDataVisualization_QCustom3DVolume_sliceIndexY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setSliceIndexZ, "setSliceIndexZ(self, value: int)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceIndexZ(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceIndexZ(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0))
        {
            sipCpp->setSliceIndexZ(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setSliceIndexZ, doc_QtDataVisualization_QCustom3DVolume_setSliceIndexZ);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_sliceIndexZ, "sliceIndexZ(self) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceIndexZ(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceIndexZ(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->sliceIndexZ();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_sliceIndexZ, doc_QtDataVisualization_QCustom3DVolume_sliceIndexZ);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setSliceIndices, "setSliceIndices(self, x: int, y: int, z: int)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceIndices(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceIndices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Biii", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->setSliceIndices(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setSliceIndices, doc_QtDataVisualization_QCustom3DVolume_setSliceIndices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setColorTable, "setColorTable(self, colors: Iterable[int])");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setColorTable(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setColorTable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector<uint>* a0;
        int a0State = 0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, sipType_QVector_1900, &a0, &a0State))
        {
            sipCpp->setColorTable(*a0);
            sipReleaseType(const_cast< ::QVector<uint> *>(a0), sipType_QVector_1900, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setColorTable, doc_QtDataVisualization_QCustom3DVolume_setColorTable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_colorTable, "colorTable(self) -> list[int]");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_colorTable(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_colorTable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            ::QVector<uint>*sipRes;

            sipRes = new ::QVector<uint>(sipCpp->colorTable());

            return sipConvertFromNewType(sipRes, sipType_QVector_1900, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_colorTable, doc_QtDataVisualization_QCustom3DVolume_colorTable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setTextureData, "setTextureData(self, data: sip.array)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureData(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QVector<unsigned char>* a0;
        int a0State = 0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ2", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, sipType_QVector_1300, &a0, &a0State))
        {
            sipCpp->setTextureData(a0);
            sipReleaseType(a0, sipType_QVector_1300, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setTextureData, doc_QtDataVisualization_QCustom3DVolume_setTextureData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_createTextureData, "createTextureData(self, images: Iterable[QImage]) -> sip.array");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_createTextureData(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_createTextureData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector< ::QImage*>* a0;
        int a0State = 0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, sipType_QVector_0101QImage, &a0, &a0State))
        {
            ::QVector<unsigned char>*sipRes;

            sipRes = sipCpp->createTextureData(*a0);
            sipReleaseType(const_cast< ::QVector< ::QImage*> *>(a0), sipType_QVector_0101QImage, a0State);

            return sipConvertFromType(sipRes, sipType_QVector_1300, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_createTextureData, doc_QtDataVisualization_QCustom3DVolume_createTextureData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_textureData, "textureData(self) -> sip.array");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureData(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            ::QVector<unsigned char>*sipRes;

            sipRes = sipCpp->textureData();

            return sipConvertFromType(sipRes, sipType_QVector_1300, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_textureData, doc_QtDataVisualization_QCustom3DVolume_textureData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setSubTextureData, "setSubTextureData(self, axis: Qt.Axis, index: int, data: PyQt5.sip.voidptr)\n"
"setSubTextureData(self, axis: Qt.Axis, index: int, image: QImage)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSubTextureData(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSubTextureData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Axis a0;
        int a1;
        const void* a2;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEiv", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, sipType_Qt_Axis, &a0, &a1, &a2))
        {
#line 237 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
            sipCpp->setSubTextureData(a0, a1, reinterpret_cast<const uchar *>(a2));
#line 898 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DVolume.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::Qt::Axis a0;
        int a1;
        const ::QImage* a2;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEiJ9", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, sipType_Qt_Axis, &a0, &a1, sipType_QImage, &a2))
        {
            sipCpp->setSubTextureData(a0, a1, *a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setSubTextureData, doc_QtDataVisualization_QCustom3DVolume_setSubTextureData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setTextureFormat, "setTextureFormat(self, format: QImage.Format)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureFormat(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setTextureFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QImage::Format a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, sipType_QImage_Format, &a0))
        {
            sipCpp->setTextureFormat(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setTextureFormat, doc_QtDataVisualization_QCustom3DVolume_setTextureFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_textureFormat, "textureFormat(self) -> QImage.Format");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureFormat(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_textureFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            ::QImage::Format sipRes;

            sipRes = sipCpp->textureFormat();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QImage_Format);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_textureFormat, doc_QtDataVisualization_QCustom3DVolume_textureFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setAlphaMultiplier, "setAlphaMultiplier(self, mult: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setAlphaMultiplier(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setAlphaMultiplier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0))
        {
            sipCpp->setAlphaMultiplier(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setAlphaMultiplier, doc_QtDataVisualization_QCustom3DVolume_setAlphaMultiplier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_alphaMultiplier, "alphaMultiplier(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_alphaMultiplier(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_alphaMultiplier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->alphaMultiplier();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_alphaMultiplier, doc_QtDataVisualization_QCustom3DVolume_alphaMultiplier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setPreserveOpacity, "setPreserveOpacity(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setPreserveOpacity(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setPreserveOpacity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0))
        {
            sipCpp->setPreserveOpacity(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setPreserveOpacity, doc_QtDataVisualization_QCustom3DVolume_setPreserveOpacity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_preserveOpacity, "preserveOpacity(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_preserveOpacity(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_preserveOpacity(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->preserveOpacity();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_preserveOpacity, doc_QtDataVisualization_QCustom3DVolume_preserveOpacity);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setUseHighDefShader, "setUseHighDefShader(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setUseHighDefShader(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setUseHighDefShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0))
        {
            sipCpp->setUseHighDefShader(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setUseHighDefShader, doc_QtDataVisualization_QCustom3DVolume_setUseHighDefShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_useHighDefShader, "useHighDefShader(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_useHighDefShader(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_useHighDefShader(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->useHighDefShader();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_useHighDefShader, doc_QtDataVisualization_QCustom3DVolume_useHighDefShader);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setDrawSlices, "setDrawSlices(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setDrawSlices(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setDrawSlices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0))
        {
            sipCpp->setDrawSlices(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setDrawSlices, doc_QtDataVisualization_QCustom3DVolume_setDrawSlices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_drawSlices, "drawSlices(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_drawSlices(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_drawSlices(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->drawSlices();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_drawSlices, doc_QtDataVisualization_QCustom3DVolume_drawSlices);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setDrawSliceFrames, "setDrawSliceFrames(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setDrawSliceFrames(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setDrawSliceFrames(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, &a0))
        {
            sipCpp->setDrawSliceFrames(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setDrawSliceFrames, doc_QtDataVisualization_QCustom3DVolume_setDrawSliceFrames);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_drawSliceFrames, "drawSliceFrames(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_drawSliceFrames(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_drawSliceFrames(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->drawSliceFrames();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_drawSliceFrames, doc_QtDataVisualization_QCustom3DVolume_drawSliceFrames);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setSliceFrameColor, "setSliceFrameColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceFrameColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceFrameColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setSliceFrameColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setSliceFrameColor, doc_QtDataVisualization_QCustom3DVolume_setSliceFrameColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_sliceFrameColor, "sliceFrameColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceFrameColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceFrameColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->sliceFrameColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_sliceFrameColor, doc_QtDataVisualization_QCustom3DVolume_sliceFrameColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setSliceFrameWidths, "setSliceFrameWidths(self, values: QVector3D)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceFrameWidths(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceFrameWidths(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setSliceFrameWidths(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setSliceFrameWidths, doc_QtDataVisualization_QCustom3DVolume_setSliceFrameWidths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_sliceFrameWidths, "sliceFrameWidths(self) -> QVector3D");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceFrameWidths(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceFrameWidths(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->sliceFrameWidths());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_sliceFrameWidths, doc_QtDataVisualization_QCustom3DVolume_sliceFrameWidths);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setSliceFrameGaps, "setSliceFrameGaps(self, values: QVector3D)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceFrameGaps(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceFrameGaps(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setSliceFrameGaps(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setSliceFrameGaps, doc_QtDataVisualization_QCustom3DVolume_setSliceFrameGaps);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_sliceFrameGaps, "sliceFrameGaps(self) -> QVector3D");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceFrameGaps(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceFrameGaps(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->sliceFrameGaps());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_sliceFrameGaps, doc_QtDataVisualization_QCustom3DVolume_sliceFrameGaps);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_setSliceFrameThicknesses, "setSliceFrameThicknesses(self, values: QVector3D)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceFrameThicknesses(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_setSliceFrameThicknesses(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setSliceFrameThicknesses(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_setSliceFrameThicknesses, doc_QtDataVisualization_QCustom3DVolume_setSliceFrameThicknesses);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_sliceFrameThicknesses, "sliceFrameThicknesses(self) -> QVector3D");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceFrameThicknesses(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_sliceFrameThicknesses(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->sliceFrameThicknesses());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_sliceFrameThicknesses, doc_QtDataVisualization_QCustom3DVolume_sliceFrameThicknesses);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume_renderSlice, "renderSlice(self, axis: Qt.Axis, index: int) -> QImage");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DVolume_renderSlice(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DVolume_renderSlice(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Axis a0;
        int a1;
        ::QtDataVisualization::QCustom3DVolume *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEi", &sipSelf, sipType_QtDataVisualization_QCustom3DVolume, &sipCpp, sipType_Qt_Axis, &a0, &a1))
        {
            ::QImage*sipRes;

            sipRes = new ::QImage(sipCpp->renderSlice(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QImage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DVolume, sipName_renderSlice, doc_QtDataVisualization_QCustom3DVolume_renderSlice);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QCustom3DVolume(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QCustom3DVolume(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QCustom3DVolume *sipCpp = reinterpret_cast< ::QtDataVisualization::QCustom3DVolume *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QCustom3DVolume)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtDataVisualization_QCustom3DItem)->ctd_cast(static_cast< ::QtDataVisualization::QCustom3DItem *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QCustom3DVolume(void *, int);}
static void release_QtDataVisualization_QCustom3DVolume(void *sipCppV, int)
{
    ::QtDataVisualization::QCustom3DVolume *sipCpp = reinterpret_cast< ::QtDataVisualization::QCustom3DVolume *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_QCustom3DVolume(Py_ssize_t);}
static void *array_QtDataVisualization_QCustom3DVolume(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QCustom3DVolume[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QCustom3DVolume(void *);}
static void array_delete_QtDataVisualization_QCustom3DVolume(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QCustom3DVolume *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_QCustom3DVolume(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QCustom3DVolume(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_QCustom3DVolume *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QCustom3DVolume(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_QCustom3DVolume(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QCustom3DVolume(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_QCustom3DVolume *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QCustom3DVolume(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QVector3D* a0;
        const ::QVector3D* a1;
        const ::QQuaternion* a2;
        int a3;
        int a4;
        int a5;
        ::QVector<unsigned char>* a6;
        int a6State = 0;
        ::QImage::Format a7;
        const ::QVector<uint>* a8;
        int a8State = 0;
        ::QObject* a9 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "#J9J9J9iiiJ2EJ1|JH", sipSelf, sipType_QVector3D, &a0, sipType_QVector3D, &a1, sipType_QQuaternion, &a2, &a3, &a4, &a5, sipType_QVector_1300, &a6, &a6State, sipType_QImage_Format, &a7, sipType_QVector_1900, &a8, &a8State, sipType_QObject, &a9, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QCustom3DVolume(*a0, *a1, *a2, a3, a4, a5, a6, a7, *a8, a9);
            sipReleaseType(a6, sipType_QVector_1300, a6State);
            sipReleaseType(const_cast< ::QVector<uint> *>(a8), sipType_QVector_1900, a8State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QCustom3DVolume[] = {{50, 255, 1}};


static PyMethodDef methods_QtDataVisualization_QCustom3DVolume[] = {
    {sipName_alphaMultiplier, meth_QtDataVisualization_QCustom3DVolume_alphaMultiplier, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_alphaMultiplier},
    {sipName_colorTable, meth_QtDataVisualization_QCustom3DVolume_colorTable, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_colorTable},
    {sipName_createTextureData, meth_QtDataVisualization_QCustom3DVolume_createTextureData, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_createTextureData},
    {sipName_drawSliceFrames, meth_QtDataVisualization_QCustom3DVolume_drawSliceFrames, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_drawSliceFrames},
    {sipName_drawSlices, meth_QtDataVisualization_QCustom3DVolume_drawSlices, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_drawSlices},
    {sipName_preserveOpacity, meth_QtDataVisualization_QCustom3DVolume_preserveOpacity, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_preserveOpacity},
    {sipName_renderSlice, meth_QtDataVisualization_QCustom3DVolume_renderSlice, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_renderSlice},
    {sipName_setAlphaMultiplier, meth_QtDataVisualization_QCustom3DVolume_setAlphaMultiplier, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setAlphaMultiplier},
    {sipName_setColorTable, meth_QtDataVisualization_QCustom3DVolume_setColorTable, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setColorTable},
    {sipName_setDrawSliceFrames, meth_QtDataVisualization_QCustom3DVolume_setDrawSliceFrames, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setDrawSliceFrames},
    {sipName_setDrawSlices, meth_QtDataVisualization_QCustom3DVolume_setDrawSlices, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setDrawSlices},
    {sipName_setPreserveOpacity, meth_QtDataVisualization_QCustom3DVolume_setPreserveOpacity, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setPreserveOpacity},
    {sipName_setSliceFrameColor, meth_QtDataVisualization_QCustom3DVolume_setSliceFrameColor, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setSliceFrameColor},
    {sipName_setSliceFrameGaps, meth_QtDataVisualization_QCustom3DVolume_setSliceFrameGaps, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setSliceFrameGaps},
    {sipName_setSliceFrameThicknesses, meth_QtDataVisualization_QCustom3DVolume_setSliceFrameThicknesses, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setSliceFrameThicknesses},
    {sipName_setSliceFrameWidths, meth_QtDataVisualization_QCustom3DVolume_setSliceFrameWidths, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setSliceFrameWidths},
    {sipName_setSliceIndexX, meth_QtDataVisualization_QCustom3DVolume_setSliceIndexX, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setSliceIndexX},
    {sipName_setSliceIndexY, meth_QtDataVisualization_QCustom3DVolume_setSliceIndexY, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setSliceIndexY},
    {sipName_setSliceIndexZ, meth_QtDataVisualization_QCustom3DVolume_setSliceIndexZ, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setSliceIndexZ},
    {sipName_setSliceIndices, meth_QtDataVisualization_QCustom3DVolume_setSliceIndices, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setSliceIndices},
    {sipName_setSubTextureData, meth_QtDataVisualization_QCustom3DVolume_setSubTextureData, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setSubTextureData},
    {sipName_setTextureData, meth_QtDataVisualization_QCustom3DVolume_setTextureData, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setTextureData},
    {sipName_setTextureDepth, meth_QtDataVisualization_QCustom3DVolume_setTextureDepth, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setTextureDepth},
    {sipName_setTextureDimensions, meth_QtDataVisualization_QCustom3DVolume_setTextureDimensions, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setTextureDimensions},
    {sipName_setTextureFormat, meth_QtDataVisualization_QCustom3DVolume_setTextureFormat, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setTextureFormat},
    {sipName_setTextureHeight, meth_QtDataVisualization_QCustom3DVolume_setTextureHeight, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setTextureHeight},
    {sipName_setTextureWidth, meth_QtDataVisualization_QCustom3DVolume_setTextureWidth, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setTextureWidth},
    {sipName_setUseHighDefShader, meth_QtDataVisualization_QCustom3DVolume_setUseHighDefShader, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_setUseHighDefShader},
    {sipName_sliceFrameColor, meth_QtDataVisualization_QCustom3DVolume_sliceFrameColor, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_sliceFrameColor},
    {sipName_sliceFrameGaps, meth_QtDataVisualization_QCustom3DVolume_sliceFrameGaps, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_sliceFrameGaps},
    {sipName_sliceFrameThicknesses, meth_QtDataVisualization_QCustom3DVolume_sliceFrameThicknesses, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_sliceFrameThicknesses},
    {sipName_sliceFrameWidths, meth_QtDataVisualization_QCustom3DVolume_sliceFrameWidths, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_sliceFrameWidths},
    {sipName_sliceIndexX, meth_QtDataVisualization_QCustom3DVolume_sliceIndexX, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_sliceIndexX},
    {sipName_sliceIndexY, meth_QtDataVisualization_QCustom3DVolume_sliceIndexY, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_sliceIndexY},
    {sipName_sliceIndexZ, meth_QtDataVisualization_QCustom3DVolume_sliceIndexZ, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_sliceIndexZ},
    {sipName_textureData, meth_QtDataVisualization_QCustom3DVolume_textureData, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_textureData},
    {sipName_textureDataWidth, meth_QtDataVisualization_QCustom3DVolume_textureDataWidth, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_textureDataWidth},
    {sipName_textureDepth, meth_QtDataVisualization_QCustom3DVolume_textureDepth, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_textureDepth},
    {sipName_textureFormat, meth_QtDataVisualization_QCustom3DVolume_textureFormat, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_textureFormat},
    {sipName_textureHeight, meth_QtDataVisualization_QCustom3DVolume_textureHeight, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_textureHeight},
    {sipName_textureWidth, meth_QtDataVisualization_QCustom3DVolume_textureWidth, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_textureWidth},
    {sipName_useHighDefShader, meth_QtDataVisualization_QCustom3DVolume_useHighDefShader, METH_VARARGS, doc_QtDataVisualization_QCustom3DVolume_useHighDefShader}
};

PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DVolume, "\1QCustom3DVolume(parent: QObject|None = None)\n"
"QCustom3DVolume(position: QVector3D, scaling: QVector3D, rotation: QQuaternion, textureWidth: int, textureHeight: int, textureDepth: int, textureData: sip.array, textureFormat: QImage.Format, colorTable: Iterable[int], parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_QCustom3DVolume[] = {
    {"sliceFrameThicknessesChanged(QVector3D)", "\1sliceFrameThicknessesChanged(self, values: QVector3D)", SIP_NULLPTR, SIP_NULLPTR},
    {"sliceFrameGapsChanged(QVector3D)", "\1sliceFrameGapsChanged(self, values: QVector3D)", SIP_NULLPTR, SIP_NULLPTR},
    {"sliceFrameWidthsChanged(QVector3D)", "\1sliceFrameWidthsChanged(self, values: QVector3D)", SIP_NULLPTR, SIP_NULLPTR},
    {"sliceFrameColorChanged(QColor)", "\1sliceFrameColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"drawSliceFramesChanged(bool)", "\1drawSliceFramesChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"drawSlicesChanged(bool)", "\1drawSlicesChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"useHighDefShaderChanged(bool)", "\1useHighDefShaderChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"preserveOpacityChanged(bool)", "\1preserveOpacityChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"alphaMultiplierChanged(float)", "\1alphaMultiplierChanged(self, mult: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"textureFormatChanged(QImage::Format)", "\1textureFormatChanged(self, format: QImage.Format)", SIP_NULLPTR, SIP_NULLPTR},
    {"textureDataChanged(QVector<uchar>*)", "\1textureDataChanged(self, data: sip.array)", SIP_NULLPTR, SIP_NULLPTR},
    {"colorTableChanged()", "\1colorTableChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"sliceIndexZChanged(int)", "\1sliceIndexZChanged(self, value: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"sliceIndexYChanged(int)", "\1sliceIndexYChanged(self, value: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"sliceIndexXChanged(int)", "\1sliceIndexXChanged(self, value: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"textureDepthChanged(int)", "\1textureDepthChanged(self, value: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"textureHeightChanged(int)", "\1textureHeightChanged(self, value: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"textureWidthChanged(int)", "\1textureWidthChanged(self, value: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_QCustom3DVolume = {
    &::QtDataVisualization::QCustom3DVolume::staticMetaObject,
    0,
    signals_QtDataVisualization_QCustom3DVolume,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QCustom3DVolume = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QCustom3DVolume,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QCustom3DVolume,
    },
    {
        sipNameNr_QCustom3DVolume,
        {0, 0, 1},
        42, methods_QtDataVisualization_QCustom3DVolume,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QCustom3DVolume,
    -1,
    -1,
    supers_QtDataVisualization_QCustom3DVolume,
    SIP_NULLPTR,
    init_type_QtDataVisualization_QCustom3DVolume,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QCustom3DVolume,
    SIP_NULLPTR,
    array_QtDataVisualization_QCustom3DVolume,
    SIP_NULLPTR,
    release_QtDataVisualization_QCustom3DVolume,
    cast_QtDataVisualization_QCustom3DVolume,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QCustom3DVolume,
    sizeof (::QtDataVisualization::QCustom3DVolume),
};
